@@ -140,6 +140,10 @@ class NetmikoSwitch(devices.GenericSwitchDevice):
                     # NOTE (vsaienko) always save configuration
                     # when configuration is applied successfully.
                     self.save_configuration(net_connect)
+        except exc.GenericSwitchException:
+            # Reraise without modification exceptions originating from this
+            # module.
+            raise
         except Exception as e:
             raise exc.GenericSwitchNetmikoConnectError(
                 config=device_utils.sanitise_config(self.config), error=e)
@@ -175,16 +179,34 @@ class NetmikoSwitch(devices.GenericSwitchDevice):
         self.send_commands_to_device(cmds)
 
     def plug_port_to_network(self, port, segmentation_id):
-        self.send_commands_to_device(
-            self._format_commands(self.PLUG_PORT_TO_NETWORK,
-                                  port=port,
-                                  segmentation_id=segmentation_id))
+        cmds = []
+        ngs_port_default_vlan = self._get_port_default_vlan()
+        if ngs_port_default_vlan:
+            cmds += self._format_commands(
+                self.DELETE_PORT,
+                port=port,
+                segmentation_id=ngs_port_default_vlan)
+        cmds += self._format_commands(
+            self.PLUG_PORT_TO_NETWORK,
+            port=port,
+            segmentation_id=segmentation_id)
+        self.send_commands_to_device(cmds)
 
     def delete_port(self, port, segmentation_id):
-        self.send_commands_to_device(
-            self._format_commands(self.DELETE_PORT,
-                                  port=port,
-                                  segmentation_id=segmentation_id))
+        cmds = self._format_commands(self.DELETE_PORT,
+                                     port=port,
+                                     segmentation_id=segmentation_id)
+        ngs_port_default_vlan = self._get_port_default_vlan()
+        if ngs_port_default_vlan:
+            cmds += self._format_commands(
+                self.ADD_NETWORK,
+                segmentation_id=ngs_port_default_vlan,
+                network_id=ngs_port_default_vlan)
+            cmds += self._format_commands(
+                self.PLUG_PORT_TO_NETWORK,
+                port=port,
+                segmentation_id=ngs_port_default_vlan)
+        self.send_commands_to_device(cmds)
 
     def send_config_set(self, net_connect, cmd_set):
         """Send a set of configuration lines to the device.
@@ -197,9 +219,17 @@ class NetmikoSwitch(devices.GenericSwitchDevice):
         return net_connect.send_config_set(config_commands=cmd_set)
 
     def save_configuration(self, net_connect):
-        """Save the device's configuration.
+        """Try to save the device's configuration.
 
         :param net_connect: a netmiko connection object.
         """
-        if self.SAVE_CONFIGURATION:
-            net_connect.send_command(self.SAVE_CONFIGURATION)
+        try:
+            net_connect.save_config()
+        except NotImplementedError:
+            if self.SAVE_CONFIGURATION:
+                for cmd in self.SAVE_CONFIGURATION:
+                    net_connect.send_command(cmd)
+            else:
+                LOG.warning("Saving config is not supported for %s,"
+                            " all changes will be lost after switch"
+                            " reboot", self.config['device_type'])
